==> vue-fullscreen-2.8.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/fullscreen/vue";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

import FullscreenApi from "@dftvue2-opentiny/vue-renderless/common/deps/fullscreen/apis";
import "@dftvue2-opentiny/vue-theme/fullscreen/index.css";
var __vue2_script = defineComponent({
  name: $prefix + "Fullscreen",
  props: {
    fullscreen: {
      type: Boolean,
      default: false
    },
    exitOnClickWrapper: {
      type: Boolean,
      default: true
    },
    fullscreenClass: {
      type: String,
      default: ""
    },
    pageOnly: {
      type: Boolean,
      default: false
    },
    teleport: {
      type: Boolean,
      default: false
    },
    zIndex: {
      type: Number,
      default: 0
    },
    beforeChange: Function
  },
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _class;
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", _vm._b({
    ref: "wrapper",
    staticClass: "tiny-fullscreen",
    class: (_class = {}, _class[_vm.fullscreenClass] = _vm.state.isFullscreen, _class),
    style: _vm.state.wrapperStyle,
    on: {
      "click": function click($event) {
        return _vm.shadeClick($event);
      },
      "keyup": _vm.exit
    }
  }, "div", _vm.$attrs, false), [_vm._t("default")], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var Fullscreen = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.8.0";
var apis = ["exit", "enter", "element", "getState", "isEnabled", "isFullscreen", "options", "request", "support", "toggle"];
apis.forEach(function(api2) {
  if (FullscreenApi[api2] && !Fullscreen[api2]) {
    Fullscreen[api2] = FullscreenApi[api2];
  }
});
Fullscreen.install = function(Vue) {
  Vue.component(Fullscreen.name, Fullscreen);
};
Fullscreen.version = version;
export {
  Fullscreen as default
};

==> vue-fullscreen-2.21.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/fullscreen/vue';
import FullscreenApi from '@opentinyvue/vue-renderless/common/deps/fullscreen/apis';
import '@opentinyvue/vue-theme/fullscreen/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Fullscreen",
  emits: ["change", "update:modelValue", "update:fullscreen"],
  props: {
    fullscreen: {
      type: Boolean,
      default: false
    },
    exitOnClickWrapper: {
      type: Boolean,
      default: true
    },
    fullscreenClass: {
      type: String,
      default: ""
    },
    pageOnly: {
      type: Boolean,
      default: false
    },
    teleport: {
      type: Boolean,
      default: false
    },
    zIndex: {
      type: Number,
      default: 0
    },
    beforeChange: Function
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _class;
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", _vm._b({
    ref: "wrapper",
    staticClass: "tiny-fullscreen",
    class: (_class = {}, _class[_vm.fullscreenClass] = _vm.state.isFullscreen, _class),
    style: _vm.state.wrapperStyle,
    on: {
      "click": function click($event) {
        return _vm.shadeClick($event);
      },
      "keyup": function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "esc", 27, $event.key, ["Esc", "Escape"])) return null;
        return _vm.exit.apply(null, arguments);
      }
    }
  }, "div", _vm.$attrs, false), [_vm._t("default")], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var Fullscreen = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.21.0";
var apis = ["exit", "enter", "element", "getState", "isEnabled", "isFullscreen", "options", "request", "support", "toggle"];
apis.forEach(function(api2) {
  if (FullscreenApi[api2] && !Fullscreen[api2]) {
    Fullscreen[api2] = FullscreenApi[api2];
  }
});
Fullscreen.install = function(Vue) {
  Vue.component(Fullscreen.name, Fullscreen);
};
Fullscreen.version = version;

export { Fullscreen as default };
